@@ -2,6 +2,7 @@
  * rtp.h  --  RTP header file (RFC 1890)
  */
 #include <sys/types.h>
+#include "sysdep.h"
 
 /*
  * The type definitions below are valid for 32-bit architectures and
@@ -61,7 +62,7 @@ typedef struct {
 #else
 #error Define one of RTP_LITTLE_ENDIAN or RTP_BIG_ENDIAN
 #endif
-    u_int16 seq;              /* sequence number */
+    unsigned int seq:16;      /* sequence number */
     u_int32 ts;               /* timestamp */
     u_int32 ssrc;             /* synchronization source */
     u_int32 csrc[1];          /* optional CSRC list */
